from setuptools import setup, find_packages
 
classifiers = [
  'Development Status :: 5 - Production/Stable',
  'Intended Audience :: Education',
  'Operating System :: Microsoft :: Windows :: Windows 10',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]
 
setup(
  name='sherok',
  version='1.8',
  description='A Python library to make everything simpler.',
  long_description=open('README.md').read() + '\n\n' + open('CHANGELOG.md').read(),
  url='',  
  author='Sreehari.S',
  author_email='sreehariaaryan@gmail.com',
  license='MIT', 
  classifiers=classifiers,
  keywords=["sh", "sherok", "python", "simpler"], 
  packages=find_packages(),
  install_requires=['randfacts', 'random', 'webbrowser', 'sys', 'time', 'pyjokes', 'requests', 'pyttsx3'] 
)